Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 38191)
+++ wp-includes/comment-template.php	(working copy)
@@ -1568,18 +1568,21 @@
  * @param array $args {
  *     Optional. Override default arguments.
  *
  *     @type string $add_below  The first part of the selector used to identify the comment to respond below.
  *                              The resulting value is passed as the first parameter to addComment.moveForm(),
  *                              concatenated as $add_below-$comment->comment_ID. Default 'comment'.
  *     @type string $respond_id The selector identifying the responding comment. Passed as the third parameter
  *                              to addComment.moveForm(), and appended to the link URL as a hash value.
  *                              Default 'respond'.
  *     @type string $reply_text The text of the Reply link. Default 'Reply'.
  *     @type string $login_text The text of the link to reply if logged out. Default 'Log in to Reply'.
  *     @type int    $depth'     The depth of the new comment. Must be greater than 0 and less than the value
  *                              of the 'thread_comments_depth' option set in Settings > Discussion. Default 0.
  *     @type string $before     The text or HTML to add before the reply link. Default empty.
  *     @type string $after      The text or HTML to add after the reply link. Default empty.
  * }
  * @param int|WP_Comment $comment Comment being replied to. Default current comment.
  * @param int|WP_Post    $post    Post ID or WP_Post object the comment is going to be displayed on.
@@ -1592,7 +1595,9 @@
 		'respond_id'    => 'respond',
 		'reply_text'    => __( 'Reply' ),
 		'reply_to_text' => __( 'Reply to %s' ),
+		'reply_title'   => '',
 		'login_text'    => __( 'Log in to Reply' ),
+		'login_title'   => '',
 		'depth'         => 0,
 		'before'        => '',
 		'after'         => ''
@@ -1629,9 +1634,10 @@
 	$args = apply_filters( 'comment_reply_link_args', $args, $comment, $post );
 
 	if ( get_option( 'comment_registration' ) && ! is_user_logged_in() ) {
-		$link = sprintf( '<a rel="nofollow" class="comment-reply-login" href="%s">%s</a>',
+		$link = sprintf( '<a rel="nofollow" class="comment-reply-login" href="%1$s" title="%3$s">%2$s</a>',
 			esc_url( wp_login_url( get_permalink() ) ),
-			$args['login_text']
+			$args['login_text'],
+			$args['login_title']
 		);
 	} else {
 		$onclick = sprintf( 'return addComment.moveForm( "%1$s-%2$s", "%2$s", "%3$s", "%4$s" )',
@@ -1638,11 +1644,12 @@
 			$args['add_below'], $comment->comment_ID, $args['respond_id'], $post->ID
 		);
 
-		$link = sprintf( "<a rel='nofollow' class='comment-reply-link' href='%s' onclick='%s' aria-label='%s'>%s</a>",
+		$link = sprintf( "<a rel='nofollow' class='comment-reply-link' href='%1\$s' onclick='%2\$s' aria-label='%3\$s' title='%5\$s'>%4\$s</a>",
 			esc_url( add_query_arg( 'replytocom', $comment->comment_ID, get_permalink( $post->ID ) ) ) . "#" . $args['respond_id'],
 			$onclick,
 			esc_attr( sprintf( $args['reply_to_text'], $comment->comment_author ) ),
-			$args['reply_text']
+			$args['reply_text'],
+			$args['reply_title']
 		);
 	}
 
@@ -1568,18 +1568,21 @@
  *     Optional. Override default arguments.
  *
- *     @type string $add_below  The first part of the selector used to identify the comment to respond below.
- *                              The resulting value is passed as the first parameter to addComment.moveForm(),
- *                              concatenated as $add_below-$comment->comment_ID. Default 'comment'.
- *     @type string $respond_id The selector identifying the responding comment. Passed as the third parameter
- *                              to addComment.moveForm(), and appended to the link URL as a hash value.
- *                              Default 'respond'.
- *     @type string $reply_text The text of the Reply link. Default 'Reply'.
- *     @type string $login_text The text of the link to reply if logged out. Default 'Log in to Reply'.
- *     @type int    $depth'     The depth of the new comment. Must be greater than 0 and less than the value
- *                              of the 'thread_comments_depth' option set in Settings > Discussion. Default 0.
- *     @type string $before     The text or HTML to add before the reply link. Default empty.
- *     @type string $after      The text or HTML to add after the reply link. Default empty.
+ *     @type string $add_below     The first part of the selector used to identify the comment to respond below.
+ *                                 The resulting value is passed as the first parameter to addComment.moveForm(),
+ *                                 concatenated as $add_below-$comment->comment_ID. Default 'comment'.
+ *     @type string $respond_id    The selector identifying the responding comment. Passed as the third parameter
+ *                                 to addComment.moveForm(), and appended to the link URL as a hash value.
+ *                                 Default 'respond'.
+ *     @type string $reply_text    The text of the Reply link. Default 'Reply'.
+ *     @type string $reply_to_text The aria-label attribute of the Reply link. Default 'Reply to %s'.
+ *     @type string $reply_title   The title attribute of the Reply link. Default '' (empty).
+ *     @type string $login_text    The text of the link to reply if logged out. Default 'Log in to Reply'.
+ *     @type string $login_title   The title attribute of the link if logged out. Default '' (empty).
+ *     @type int    $depth'        The depth of the new comment. Must be greater than 0 and less than the value
+ *                                 of the 'thread_comments_depth' option set in Settings > Discussion. Default 0.
+ *     @type string $before        The text or HTML to add before the reply link. Default empty.
+ *     @type string $after         The text or HTML to add after the reply link. Default empty.
  * }
  * @param int|WP_Comment $comment Comment being replied to. Default current comment.
